==> abiword-0.9.0.tar.gz: abiword-0.9.0/abi/autogen.sh <==
#!/bin/sh
# 
# Run this before configure
#
# This file blatantly ripped off from subversion.
#
# Note: this dependency on Perl is fine: only SVN developers use autogen.sh
#       and we can state that dev people need Perl on their machine
#

set -e

if autoconf --version | head -1 | grep '2\.5' > /dev/null 2>&1; then
  cp configure.in-v2.50 configure.in
else
  cp configure.in-v2.13 configure.in
fi

automake --version | perl -ne 'if (/\(GNU automake\) ([0-9].[0-9])/) {print;  if ($1 < 1.4) {exit 1;}}'

if [ $? -ne 0 ]; then
    echo "Error: you need automake 1.4 or later.  Please upgrade."
    exit 1
fi

if ! test -d `aclocal --print-ac-dir`; then
  echo "Bad aclocal (automake) installation"
  exit 1
fi

echo "Selecting the correct m4 script..."

for script in `cd ac-helpers/fallback; echo *.m4`; do
  if test -r `aclocal --print-ac-dir`/$script; then
    # Perhaps it was installed recently
    rm -f ac-helpers/$script
  else
    # Use the fallback script
    cp ac-helpers/fallback/$script ac-helpers/$script
  fi
done

# Produce aclocal.m4, so autoconf gets the automake macros it needs
echo "Creating aclocal.m4..."
aclocal -I ac-helpers

autoheader

# Produce all the `Makefile.in's, verbosely, and create neat missing things
# like `libtool', `install-sh', etc.
automake --add-missing --verbose --foreign

# If there's a config.cache file, we may need to delete it.  
# If we have an existing configure script, save a copy for comparison.
if [ -f config.cache ] && [ -f configure ]; then
  cp configure configure.$$.tmp
fi

# Produce ./configure
echo "Creating configure..."
autoconf

echo ""
echo "You can run ./configure now."
echo ""

==> abiword-0.9.2.tar.gz: abiword-0.9.2/abi/autogen.sh <==
#!/bin/sh
# 
# Run this before configure
#
# This file blatantly ripped off from subversion.
#
# Note: this dependency on Perl is fine: only SVN developers use autogen.sh
#       and we can state that dev people need Perl on their machine
#

set -e

if autoconf --version | head -1 | grep '2\.5' > /dev/null 2>&1; then
  cp configure.in-v2.50 configure.in
else
  cp configure.in-v2.13 configure.in
fi

automake --version | perl -ne 'if (/\(GNU automake\) ([0-9].[0-9])/) {print;  if ($1 < 1.4) {exit 1;}}'

if [ $? -ne 0 ]; then
    echo "Error: you need automake 1.4 or later.  Please upgrade."
    exit 1
fi

if test ! -d `aclocal --print-ac-dir`; then
  echo "Bad aclocal (automake) installation"
  exit 1
fi

echo "Selecting the correct m4 script..."

for script in `cd ac-helpers/fallback; echo *.m4`; do
  if test -r `aclocal --print-ac-dir`/$script; then
    # Perhaps it was installed recently
    rm -f ac-helpers/$script
  else
    # Use the fallback script
    cp ac-helpers/fallback/$script ac-helpers/$script
  fi
done

# Produce aclocal.m4, so autoconf gets the automake macros it needs
echo "Creating aclocal.m4..."
aclocal -I ac-helpers

autoheader

# Produce all the `Makefile.in's, verbosely, and create neat missing things
# like `libtool', `install-sh', etc.
automake --add-missing --verbose --foreign

# If there's a config.cache file, we may need to delete it.  
# If we have an existing configure script, save a copy for comparison.
if [ -f config.cache ] && [ -f configure ]; then
  cp configure configure.$$.tmp
fi

# Produce ./configure
echo "Creating configure..."
autoconf

echo ""
echo "You can run ./configure now."
echo ""
